@@ -8,7 +8,8 @@ def create_celery_app(project_folder):
     from celery import Celery
     celery_settings = get_settings(settings_type='celery')
     celery_app = Celery(__name__)
-    celery_settings['imports'] = collect_app_tasks(project_folder=project_folder) + ['handlers', 'routes']
+    celery_settings['imports'] = collect_app_tasks(project_folder=project_folder) + ['handlers', 'routes', 'models',
+                                                                                     'config']
     celery_app.config_from_object(celery_settings, force=True)
     import_tasks = collect_framework_tasks()
     for pkg, file in import_tasks:
